==> trellis_python-2.8.0.tar.gz: trellis_python-2.8.0/CHANGELOG.md <==
# Changelog

## 2.8.0 (2024-11-19)

Full Changelog: [v2.7.0...v2.8.0](https://github.com/Trellis-insights/trellis-python-sdk/compare/v2.7.0...v2.8.0)

### Features

* **api:** api update ([#34](https://github.com/Trellis-insights/trellis-python-sdk/issues/34)) ([78e7e72](https://github.com/Trellis-insights/trellis-python-sdk/commit/78e7e7296a8dd92930c7686464038c4db3eb2e69))


### Chores

* rebuild project due to codegen change ([#31](https://github.com/Trellis-insights/trellis-python-sdk/issues/31)) ([8f4e063](https://github.com/Trellis-insights/trellis-python-sdk/commit/8f4e063760250eb837c5108c10fa008fb972cd36))
* rebuild project due to codegen change ([#33](https://github.com/Trellis-insights/trellis-python-sdk/issues/33)) ([f2741e6](https://github.com/Trellis-insights/trellis-python-sdk/commit/f2741e603647352259927f36690be8749ef95ad1))

## 2.7.0 (2024-11-15)

Full Changelog: [v2.6.0...v2.7.0](https://github.com/Trellis-insights/trellis-python-sdk/compare/v2.6.0...v2.7.0)

### Features

* **api:** api update ([#28](https://github.com/Trellis-insights/trellis-python-sdk/issues/28)) ([c9dd3eb](https://github.com/Trellis-insights/trellis-python-sdk/commit/c9dd3ebd388450811ce803cf2d50db12a953324c))

## 2.6.0 (2024-11-14)

Full Changelog: [v2.5.0...v2.6.0](https://github.com/Trellis-insights/trellis-python-sdk/compare/v2.5.0...v2.6.0)

### Features

* **api:** api update ([#25](https://github.com/Trellis-insights/trellis-python-sdk/issues/25)) ([5d2edd6](https://github.com/Trellis-insights/trellis-python-sdk/commit/5d2edd6542a79ba9869c85d4e5393c22dcef5b30))

## 2.5.0 (2024-11-12)

Full Changelog: [v2.4.0...v2.5.0](https://github.com/Trellis-insights/trellis-python-sdk/compare/v2.4.0...v2.5.0)

### Features

* **api:** api update ([#23](https://github.com/Trellis-insights/trellis-python-sdk/issues/23)) ([ff17ba8](https://github.com/Trellis-insights/trellis-python-sdk/commit/ff17ba891278e8a0b020dd96ec7779d72ead61c4))


### Chores

* rebuild project due to codegen change ([#21](https://github.com/Trellis-insights/trellis-python-sdk/issues/21)) ([d837a3c](https://github.com/Trellis-insights/trellis-python-sdk/commit/d837a3ccc1471ca619f97ee42f7014ee1711b8b0))

## 2.4.0 (2024-11-11)

Full Changelog: [v2.3.0...v2.4.0](https://github.com/Trellis-insights/trellis-python-sdk/compare/v2.3.0...v2.4.0)

### Features

* **api:** api update ([#18](https://github.com/Trellis-insights/trellis-python-sdk/issues/18)) ([bb5ab13](https://github.com/Trellis-insights/trellis-python-sdk/commit/bb5ab132cfc7f0576aa5ea0ed21e8e3bb622d684))

## 2.3.0 (2024-11-10)

Full Changelog: [v2.2.0...v2.3.0](https://github.com/Trellis-insights/trellis-python-sdk/compare/v2.2.0...v2.3.0)

### Features

* **api:** api update ([#15](https://github.com/Trellis-insights/trellis-python-sdk/issues/15)) ([6b673e1](https://github.com/Trellis-insights/trellis-python-sdk/commit/6b673e1a993e881471a55a5a16923a44b5bc9eae))

## 2.2.0 (2024-11-10)

Full Changelog: [v2.1.0...v2.2.0](https://github.com/Trellis-insights/trellis-python-sdk/compare/v2.1.0...v2.2.0)

### Features

* **api:** manual updates ([#12](https://github.com/Trellis-insights/trellis-python-sdk/issues/12)) ([f17a6d7](https://github.com/Trellis-insights/trellis-python-sdk/commit/f17a6d79b8e757344a6ddef9b5210837b7907e65))

## 2.1.0 (2024-11-10)

Full Changelog: [v2.0.0...v2.1.0](https://github.com/Trellis-insights/trellis-python-sdk/compare/v2.0.0...v2.1.0)

### Features

* **api:** api update ([#10](https://github.com/Trellis-insights/trellis-python-sdk/issues/10)) ([ebdfa0f](https://github.com/Trellis-insights/trellis-python-sdk/commit/ebdfa0fc9e6ca38ad74fa0f7a4cc09a6d0e5f824))
* **api:** api update ([#8](https://github.com/Trellis-insights/trellis-python-sdk/issues/8)) ([d7eadfc](https://github.com/Trellis-insights/trellis-python-sdk/commit/d7eadfcb12a6433ef6e2fd8e855d101ed0448a5f))

## 2.0.0 (2024-11-07)

Full Changelog: [v1.0.0...v2.0.0](https://github.com/Trellis-insights/trellis-python-sdk/compare/v1.0.0...v2.0.0)

### Chores

* update SDK settings ([#5](https://github.com/Trellis-insights/trellis-python-sdk/issues/5)) ([d244250](https://github.com/Trellis-insights/trellis-python-sdk/commit/d244250f38ee062e0885904076fd841ca27593f1))

## 1.0.0 (2024-11-04)

Full Changelog: [v0.0.1-alpha.0...v1.0.0](https://github.com/Trellis-insights/trellis-python-sdk/compare/v0.0.1-alpha.0...v1.0.0)

### Chores

* go live ([#1](https://github.com/Trellis-insights/trellis-python-sdk/issues/1)) ([15992d4](https://github.com/Trellis-insights/trellis-python-sdk/commit/15992d4245d6e4d1c8a82c18c854ffa74d8090c4))
* update SDK settings ([#3](https://github.com/Trellis-insights/trellis-python-sdk/issues/3)) ([161e906](https://github.com/Trellis-insights/trellis-python-sdk/commit/161e90633a5a1d70c5c8a87a507bbca521ecb2ba))

==> trellis_python-2.9.0.tar.gz: trellis_python-2.9.0/CHANGELOG.md <==
# Changelog

## 2.9.0 (2024-11-20)

Full Changelog: [v2.8.0...v2.9.0](https://github.com/Trellis-insights/trellis-python-sdk/compare/v2.8.0...v2.9.0)

### Features

* **api:** api update ([#36](https://github.com/Trellis-insights/trellis-python-sdk/issues/36)) ([28bd739](https://github.com/Trellis-insights/trellis-python-sdk/commit/28bd739007f8abf80c585972688b070247089f4b))

## 2.8.0 (2024-11-19)

Full Changelog: [v2.7.0...v2.8.0](https://github.com/Trellis-insights/trellis-python-sdk/compare/v2.7.0...v2.8.0)

### Features

* **api:** api update ([#34](https://github.com/Trellis-insights/trellis-python-sdk/issues/34)) ([78e7e72](https://github.com/Trellis-insights/trellis-python-sdk/commit/78e7e7296a8dd92930c7686464038c4db3eb2e69))


### Chores

* rebuild project due to codegen change ([#31](https://github.com/Trellis-insights/trellis-python-sdk/issues/31)) ([8f4e063](https://github.com/Trellis-insights/trellis-python-sdk/commit/8f4e063760250eb837c5108c10fa008fb972cd36))
* rebuild project due to codegen change ([#33](https://github.com/Trellis-insights/trellis-python-sdk/issues/33)) ([f2741e6](https://github.com/Trellis-insights/trellis-python-sdk/commit/f2741e603647352259927f36690be8749ef95ad1))

## 2.7.0 (2024-11-15)

Full Changelog: [v2.6.0...v2.7.0](https://github.com/Trellis-insights/trellis-python-sdk/compare/v2.6.0...v2.7.0)

### Features

* **api:** api update ([#28](https://github.com/Trellis-insights/trellis-python-sdk/issues/28)) ([c9dd3eb](https://github.com/Trellis-insights/trellis-python-sdk/commit/c9dd3ebd388450811ce803cf2d50db12a953324c))

## 2.6.0 (2024-11-14)

Full Changelog: [v2.5.0...v2.6.0](https://github.com/Trellis-insights/trellis-python-sdk/compare/v2.5.0...v2.6.0)

### Features

* **api:** api update ([#25](https://github.com/Trellis-insights/trellis-python-sdk/issues/25)) ([5d2edd6](https://github.com/Trellis-insights/trellis-python-sdk/commit/5d2edd6542a79ba9869c85d4e5393c22dcef5b30))

## 2.5.0 (2024-11-12)

Full Changelog: [v2.4.0...v2.5.0](https://github.com/Trellis-insights/trellis-python-sdk/compare/v2.4.0...v2.5.0)

### Features

* **api:** api update ([#23](https://github.com/Trellis-insights/trellis-python-sdk/issues/23)) ([ff17ba8](https://github.com/Trellis-insights/trellis-python-sdk/commit/ff17ba891278e8a0b020dd96ec7779d72ead61c4))


### Chores

* rebuild project due to codegen change ([#21](https://github.com/Trellis-insights/trellis-python-sdk/issues/21)) ([d837a3c](https://github.com/Trellis-insights/trellis-python-sdk/commit/d837a3ccc1471ca619f97ee42f7014ee1711b8b0))

## 2.4.0 (2024-11-11)

Full Changelog: [v2.3.0...v2.4.0](https://github.com/Trellis-insights/trellis-python-sdk/compare/v2.3.0...v2.4.0)

### Features

* **api:** api update ([#18](https://github.com/Trellis-insights/trellis-python-sdk/issues/18)) ([bb5ab13](https://github.com/Trellis-insights/trellis-python-sdk/commit/bb5ab132cfc7f0576aa5ea0ed21e8e3bb622d684))

## 2.3.0 (2024-11-10)

Full Changelog: [v2.2.0...v2.3.0](https://github.com/Trellis-insights/trellis-python-sdk/compare/v2.2.0...v2.3.0)

### Features

* **api:** api update ([#15](https://github.com/Trellis-insights/trellis-python-sdk/issues/15)) ([6b673e1](https://github.com/Trellis-insights/trellis-python-sdk/commit/6b673e1a993e881471a55a5a16923a44b5bc9eae))

## 2.2.0 (2024-11-10)

Full Changelog: [v2.1.0...v2.2.0](https://github.com/Trellis-insights/trellis-python-sdk/compare/v2.1.0...v2.2.0)

### Features

* **api:** manual updates ([#12](https://github.com/Trellis-insights/trellis-python-sdk/issues/12)) ([f17a6d7](https://github.com/Trellis-insights/trellis-python-sdk/commit/f17a6d79b8e757344a6ddef9b5210837b7907e65))

## 2.1.0 (2024-11-10)

Full Changelog: [v2.0.0...v2.1.0](https://github.com/Trellis-insights/trellis-python-sdk/compare/v2.0.0...v2.1.0)

### Features

* **api:** api update ([#10](https://github.com/Trellis-insights/trellis-python-sdk/issues/10)) ([ebdfa0f](https://github.com/Trellis-insights/trellis-python-sdk/commit/ebdfa0fc9e6ca38ad74fa0f7a4cc09a6d0e5f824))
* **api:** api update ([#8](https://github.com/Trellis-insights/trellis-python-sdk/issues/8)) ([d7eadfc](https://github.com/Trellis-insights/trellis-python-sdk/commit/d7eadfcb12a6433ef6e2fd8e855d101ed0448a5f))

## 2.0.0 (2024-11-07)

Full Changelog: [v1.0.0...v2.0.0](https://github.com/Trellis-insights/trellis-python-sdk/compare/v1.0.0...v2.0.0)

### Chores

* update SDK settings ([#5](https://github.com/Trellis-insights/trellis-python-sdk/issues/5)) ([d244250](https://github.com/Trellis-insights/trellis-python-sdk/commit/d244250f38ee062e0885904076fd841ca27593f1))

## 1.0.0 (2024-11-04)

Full Changelog: [v0.0.1-alpha.0...v1.0.0](https://github.com/Trellis-insights/trellis-python-sdk/compare/v0.0.1-alpha.0...v1.0.0)

### Chores

* go live ([#1](https://github.com/Trellis-insights/trellis-python-sdk/issues/1)) ([15992d4](https://github.com/Trellis-insights/trellis-python-sdk/commit/15992d4245d6e4d1c8a82c18c854ffa74d8090c4))
* update SDK settings ([#3](https://github.com/Trellis-insights/trellis-python-sdk/issues/3)) ([161e906](https://github.com/Trellis-insights/trellis-python-sdk/commit/161e90633a5a1d70c5c8a87a507bbca521ecb2ba))
